summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorDaniƫl van Noord <13665637+DanielNoord@users.noreply.github.com>2022-05-10 11:38:53 +0200
committerGitHub <noreply@github.com>2022-05-10 11:38:53 +0200
commit7c915217b0513b34c179c409cff983352f685bf5 (patch)
tree8b66f795e83405e698453ecc3051fdc25c42576d
parent133e2e59394528e3c2c16fd7ea921796bfcbef8d (diff)
downloadpylint-git-7c915217b0513b34c179c409cff983352f685bf5.tar.gz
Use main instead of master as main checker name (#6569)
Co-authored-by: Pierre Sassoulas <pierre.sassoulas@gmail.com>
-rw-r--r--.github/ISSUE_TEMPLATE/BUG-REPORT.yml2
-rw-r--r--ChangeLog4
-rw-r--r--doc/data/messages/b/broken-collections-callable/pylintrc2
-rw-r--r--doc/data/messages/c/confusing-consecutive-elif/pylintrc2
-rw-r--r--doc/data/messages/m/missing-return-doc/pylintrc2
-rw-r--r--doc/data/messages/m/missing-return-type-doc/pylintrc2
-rw-r--r--doc/data/messages/m/missing-yield-doc/pylintrc2
-rw-r--r--doc/data/messages/m/missing-yield-type-doc/pylintrc2
-rw-r--r--doc/data/messages/r/redefined-loop-name/pylintrc2
-rw-r--r--doc/data/messages/w/while-used/pylintrc2
-rwxr-xr-xdoc/exts/pylint_extensions.py2
-rw-r--r--doc/faq.rst4
-rw-r--r--doc/technical_reference/startup.rst2
-rw-r--r--doc/whatsnew/1.7.rst4
-rw-r--r--doc/whatsnew/2.11.rst2
-rw-r--r--doc/whatsnew/2.14.rst4
-rw-r--r--examples/pylintrc2
-rw-r--r--pylint/config/arguments_manager.py4
-rw-r--r--pylint/constants.py4
-rw-r--r--pylint/extensions/docparams.py2
-rw-r--r--pylint/extensions/docparams.rst2
-rw-r--r--pylint/utils/docs.py2
-rw-r--r--pylintrc2
-rw-r--r--tests/benchmark/test_baseline_benchmarks.py30
-rw-r--r--tests/config/functional/setup_cfg/identical_name_in_flake8/setup.cfg2
-rw-r--r--tests/config/functional/setup_cfg/issue_4272/option_in_wrong_section.cfg4
-rw-r--r--tests/config/functional/toml/issue_4746/loaded_plugin_does_not_exists.toml2
-rw-r--r--tests/functional/a/alternative/alternative_union_syntax.rc2
-rw-r--r--tests/functional/a/alternative/alternative_union_syntax_error.rc2
-rw-r--r--tests/functional/a/alternative/alternative_union_syntax_py37.rc2
-rw-r--r--tests/functional/d/deprecated/deprecated_module_py39_earlier_pyversion.rc2
-rw-r--r--tests/functional/e/.#emacs_file_lock_by_conf.rc2
-rw-r--r--tests/functional/e/.#emacs_file_lock_redefined_conf.rc2
-rw-r--r--tests/functional/ext/bad_builtin/bad_builtin_extension.rc2
-rw-r--r--tests/functional/ext/bad_builtin/bad_builtins.rc2
-rw-r--r--tests/functional/ext/broad_try_clause/broad_try_clause_extension.rc2
-rw-r--r--tests/functional/ext/check_elif/check_elif.rc2
-rw-r--r--tests/functional/ext/code_style/cs_consider_using_assignment_expr.rc2
-rw-r--r--tests/functional/ext/code_style/cs_consider_using_namedtuple_or_dataclass.rc2
-rw-r--r--tests/functional/ext/code_style/cs_consider_using_tuple.rc2
-rw-r--r--tests/functional/ext/code_style/cs_py_version_35.rc2
-rw-r--r--tests/functional/ext/comparetozero/comparetozero.rc2
-rw-r--r--tests/functional/ext/comparison_placement/misplaced_comparison_constant.rc2
-rw-r--r--tests/functional/ext/confusing_elif/confusing_elif.rc2
-rw-r--r--tests/functional/ext/consider_ternary_expression/consider_ternary_expression.rc2
-rw-r--r--tests/functional/ext/docparams/docparams.rc2
-rw-r--r--tests/functional/ext/docparams/missing_param_doc.rc2
-rw-r--r--tests/functional/ext/docparams/parameter/missing_param_doc.rc2
-rw-r--r--tests/functional/ext/docparams/parameter/missing_param_doc_required.rc2
-rw-r--r--tests/functional/ext/docparams/parameter/missing_param_doc_required_Google.rc2
-rw-r--r--tests/functional/ext/docparams/parameter/missing_param_doc_required_Numpy.rc2
-rw-r--r--tests/functional/ext/docparams/parameter/missing_param_doc_required_Sphinx.rc2
-rw-r--r--tests/functional/ext/docparams/parameter/missing_param_doc_required_min_length.rc2
-rw-r--r--tests/functional/ext/docparams/parameter/missing_param_doc_required_no_doc_rgx_check_init.rc2
-rw-r--r--tests/functional/ext/docparams/parameter/missing_param_doc_required_no_doc_rgx_check_none.rc2
-rw-r--r--tests/functional/ext/docparams/parameter/missing_param_doc_required_no_doc_rgx_default.rc2
-rw-r--r--tests/functional/ext/docparams/parameter/missing_param_doc_required_no_doc_rgx_test_all.rc2
-rw-r--r--tests/functional/ext/docparams/raise/missing_raises_doc.rc2
-rw-r--r--tests/functional/ext/docparams/raise/missing_raises_doc_Google.rc2
-rw-r--r--tests/functional/ext/docparams/raise/missing_raises_doc_Numpy.rc2
-rw-r--r--tests/functional/ext/docparams/raise/missing_raises_doc_Sphinx.rc2
-rw-r--r--tests/functional/ext/docparams/raise/missing_raises_doc_required.rc2
-rw-r--r--tests/functional/ext/docparams/raise/missing_raises_doc_required_Google.rc2
-rw-r--r--tests/functional/ext/docparams/raise/missing_raises_doc_required_Numpy.rc2
-rw-r--r--tests/functional/ext/docparams/raise/missing_raises_doc_required_Sphinx.rc2
-rw-r--r--tests/functional/ext/docparams/raise/missing_raises_doc_required_exc_inheritance.rc2
-rw-r--r--tests/functional/ext/docparams/return/missing_return_doc.rc2
-rw-r--r--tests/functional/ext/docparams/return/missing_return_doc_Google.rc2
-rw-r--r--tests/functional/ext/docparams/return/missing_return_doc_Numpy.rc2
-rw-r--r--tests/functional/ext/docparams/return/missing_return_doc_Sphinx.rc2
-rw-r--r--tests/functional/ext/docparams/return/missing_return_doc_required.rc2
-rw-r--r--tests/functional/ext/docparams/return/missing_return_doc_required_Google.rc2
-rw-r--r--tests/functional/ext/docparams/return/missing_return_doc_required_Numpy.rc2
-rw-r--r--tests/functional/ext/docparams/return/missing_return_doc_required_Sphinx.rc2
-rw-r--r--tests/functional/ext/docparams/useless_type_doc.rc2
-rw-r--r--tests/functional/ext/docparams/yield/missing_yield_doc.rc2
-rw-r--r--tests/functional/ext/docparams/yield/missing_yield_doc_Google.rc2
-rw-r--r--tests/functional/ext/docparams/yield/missing_yield_doc_Numpy.rc2
-rw-r--r--tests/functional/ext/docparams/yield/missing_yield_doc_Sphinx.rc2
-rw-r--r--tests/functional/ext/docparams/yield/missing_yield_doc_required.rc2
-rw-r--r--tests/functional/ext/docparams/yield/missing_yield_doc_required_Google.rc2
-rw-r--r--tests/functional/ext/docparams/yield/missing_yield_doc_required_Numpy.rc2
-rw-r--r--tests/functional/ext/docparams/yield/missing_yield_doc_required_Sphinx.rc2
-rw-r--r--tests/functional/ext/docstyle/docstyle_first_line_empty.rc2
-rw-r--r--tests/functional/ext/docstyle/docstyle_quotes.rc2
-rw-r--r--tests/functional/ext/empty_comment/empty_comment.rc2
-rw-r--r--tests/functional/ext/emptystring/empty_string_comparison.rc2
-rw-r--r--tests/functional/ext/eq_without_hash/eq_without_hash.rc2
-rw-r--r--tests/functional/ext/for_any_all/for_any_all.rc2
-rw-r--r--tests/functional/ext/mccabe/mccabe.rc2
-rw-r--r--tests/functional/ext/no_self_use/no_self_use.rc2
-rw-r--r--tests/functional/ext/overlapping_exceptions/overlapping_exceptions.rc2
-rw-r--r--tests/functional/ext/plugin_does_not_exists.rc2
-rw-r--r--tests/functional/ext/private_import/private_import.rc2
-rw-r--r--tests/functional/ext/redefined_loop_name/redefined_loop_name.rc2
-rw-r--r--tests/functional/ext/redefined_loop_name/reused_outer_loop_variable.rc2
-rw-r--r--tests/functional/ext/redefined_variable_type/redefined_variable_type.rc2
-rw-r--r--tests/functional/ext/redefined_variable_type/regression_newtype_fstring.rc2
-rw-r--r--tests/functional/ext/set_membership/use_set_membership.rc2
-rw-r--r--tests/functional/ext/typing/typing_broken_callable.rc2
-rw-r--r--tests/functional/ext/typing/typing_broken_callable_deprecated_alias.rc2
-rw-r--r--tests/functional/ext/typing/typing_broken_callable_future_import.rc2
-rw-r--r--tests/functional/ext/typing/typing_broken_noreturn.rc2
-rw-r--r--tests/functional/ext/typing/typing_broken_noreturn_future_import.rc2
-rw-r--r--tests/functional/ext/typing/typing_broken_noreturn_py372.rc2
-rw-r--r--tests/functional/ext/typing/typing_consider_using_alias.rc2
-rw-r--r--tests/functional/ext/typing/typing_consider_using_alias_without_future.rc2
-rw-r--r--tests/functional/ext/typing/typing_consider_using_union.rc2
-rw-r--r--tests/functional/ext/typing/typing_consider_using_union_py310.rc2
-rw-r--r--tests/functional/ext/typing/typing_consider_using_union_without_future.rc2
-rw-r--r--tests/functional/ext/typing/typing_deprecated_alias.rc2
-rw-r--r--tests/functional/ext/while_used/while_used.rc2
-rw-r--r--tests/functional/p/protected_access_special_methods_off.rc2
-rw-r--r--tests/functional/p/protected_access_special_methods_on.rc2
-rw-r--r--tests/functional/p/py_version_35.rc2
-rw-r--r--tests/functional/r/regression/regression_issue_4631.rc2
-rw-r--r--tests/functional/u/unsupported/unsupported_version_for_final.rc2
-rw-r--r--tests/message/unittest_message_id_store.py2
-rw-r--r--tests/regrtest_data/dummy_plugin.rc2
-rw-r--r--tests/test_check_parallel.py2
-rw-r--r--tests/test_self.py14
-rw-r--r--tests/testutils/data/init_hook.rc2
122 files changed, 154 insertions, 144 deletions
diff --git a/.github/ISSUE_TEMPLATE/BUG-REPORT.yml b/.github/ISSUE_TEMPLATE/BUG-REPORT.yml
index 9e0eb2b91..640c1bfe3 100644
--- a/.github/ISSUE_TEMPLATE/BUG-REPORT.yml
+++ b/.github/ISSUE_TEMPLATE/BUG-REPORT.yml
@@ -35,7 +35,7 @@ body:
placeholder: |
# Leave this blank if the configuration is not relevant!
- [MASTER]
+ [MAIN]
load-plugins=
pylint.extensions.code_style
diff --git a/ChangeLog b/ChangeLog
index 087a5fc9d..22f6285d3 100644
--- a/ChangeLog
+++ b/ChangeLog
@@ -40,6 +40,10 @@ Release date: TBA
Closes #6101
+* The main checker name is now ``main`` instead of ``master``. The configuration does not need to be updated as sections' name are optional.
+
+ Closes #5467
+
* Added new checker ``typevar-name-mismatch``: TypeVar must be assigned to a variable with the same name as its name argument.
Closes #5224
diff --git a/doc/data/messages/b/broken-collections-callable/pylintrc b/doc/data/messages/b/broken-collections-callable/pylintrc
index c26e81d1c..d075a593e 100644
--- a/doc/data/messages/b/broken-collections-callable/pylintrc
+++ b/doc/data/messages/b/broken-collections-callable/pylintrc
@@ -1,3 +1,3 @@
-[master]
+[main]
py-version=3.9
load-plugins=pylint.extensions.typing
diff --git a/doc/data/messages/c/confusing-consecutive-elif/pylintrc b/doc/data/messages/c/confusing-consecutive-elif/pylintrc
index 6a11b2c09..6ceabfd96 100644
--- a/doc/data/messages/c/confusing-consecutive-elif/pylintrc
+++ b/doc/data/messages/c/confusing-consecutive-elif/pylintrc
@@ -1,2 +1,2 @@
-[MASTER]
+[MAIN]
load-plugins=pylint.extensions.confusing_elif
diff --git a/doc/data/messages/m/missing-return-doc/pylintrc b/doc/data/messages/m/missing-return-doc/pylintrc
index 3928037cb..b1fdaf6d1 100644
--- a/doc/data/messages/m/missing-return-doc/pylintrc
+++ b/doc/data/messages/m/missing-return-doc/pylintrc
@@ -1,4 +1,4 @@
-[master]
+[main]
load-plugins=pylint.extensions.docparams
[Parameter_documentation]
diff --git a/doc/data/messages/m/missing-return-type-doc/pylintrc b/doc/data/messages/m/missing-return-type-doc/pylintrc
index 3928037cb..b1fdaf6d1 100644
--- a/doc/data/messages/m/missing-return-type-doc/pylintrc
+++ b/doc/data/messages/m/missing-return-type-doc/pylintrc
@@ -1,4 +1,4 @@
-[master]
+[main]
load-plugins=pylint.extensions.docparams
[Parameter_documentation]
diff --git a/doc/data/messages/m/missing-yield-doc/pylintrc b/doc/data/messages/m/missing-yield-doc/pylintrc
index 1416fbd0b..ba9528325 100644
--- a/doc/data/messages/m/missing-yield-doc/pylintrc
+++ b/doc/data/messages/m/missing-yield-doc/pylintrc
@@ -1,4 +1,4 @@
-[master]
+[main]
load-plugins=pylint.extensions.docparams
[Parameter_documentation]
diff --git a/doc/data/messages/m/missing-yield-type-doc/pylintrc b/doc/data/messages/m/missing-yield-type-doc/pylintrc
index 1416fbd0b..ba9528325 100644
--- a/doc/data/messages/m/missing-yield-type-doc/pylintrc
+++ b/doc/data/messages/m/missing-yield-type-doc/pylintrc
@@ -1,4 +1,4 @@
-[master]
+[main]
load-plugins=pylint.extensions.docparams
[Parameter_documentation]
diff --git a/doc/data/messages/r/redefined-loop-name/pylintrc b/doc/data/messages/r/redefined-loop-name/pylintrc
index 2785fc59e..5bdbdbe6e 100644
--- a/doc/data/messages/r/redefined-loop-name/pylintrc
+++ b/doc/data/messages/r/redefined-loop-name/pylintrc
@@ -1,2 +1,2 @@
-[MASTER]
+[MAIN]
load-plugins=pylint.extensions.redefined_loop_name,
diff --git a/doc/data/messages/w/while-used/pylintrc b/doc/data/messages/w/while-used/pylintrc
index 90fe02d2d..eebe8239f 100644
--- a/doc/data/messages/w/while-used/pylintrc
+++ b/doc/data/messages/w/while-used/pylintrc
@@ -1,2 +1,2 @@
-[master]
+[main]
load-plugins=pylint.extensions.while_used
diff --git a/doc/exts/pylint_extensions.py b/doc/exts/pylint_extensions.py
index 8dbf5b730..15511a662 100755
--- a/doc/exts/pylint_extensions.py
+++ b/doc/exts/pylint_extensions.py
@@ -59,7 +59,7 @@ def builder_inited(app: Optional[Sphinx]) -> None:
stream.write("\n")
stream.write(
"You can activate any or all of these extensions "
- "by adding a ``load-plugins`` line to the ``MASTER`` "
+ "by adding a ``load-plugins`` line to the ``MAIN`` "
"section of your ``.pylintrc``, for example::\n"
)
stream.write(
diff --git a/doc/faq.rst b/doc/faq.rst
index 2b6232c46..21398c175 100644
--- a/doc/faq.rst
+++ b/doc/faq.rst
@@ -203,7 +203,7 @@ any formatting accepted by ConfigParser, e.g.
.. code-block:: ini
- [MASTER]
+ [MAIN]
output-format = colorized
[Messages Control]
@@ -221,7 +221,7 @@ Alternatively, if you use ``pyproject.toml``, e.g.
.. code-block:: toml
- [tool.pylint.master]
+ [tool.pylint.main]
output-format = "colorized"
[tool.pylint.messages_control]
diff --git a/doc/technical_reference/startup.rst b/doc/technical_reference/startup.rst
index 5a2063d4a..92913ef7f 100644
--- a/doc/technical_reference/startup.rst
+++ b/doc/technical_reference/startup.rst
@@ -8,7 +8,7 @@ It does some basic checking of the given command line options to
find the initial hook to run,
find the config file to use,
and find which plugins have been specified.
-It can then create the master :class:`.pylint.lint.PyLinter` instance
+It can then create the main :class:`.pylint.lint.PyLinter` instance
and initialise it with the config file and plugins that were discovered
when preprocessing the command line options.
Finally the :class:`.pylint.lint.Run` object launches any child linters
diff --git a/doc/whatsnew/1.7.rst b/doc/whatsnew/1.7.rst
index 22256bc52..5863d83bb 100644
--- a/doc/whatsnew/1.7.rst
+++ b/doc/whatsnew/1.7.rst
@@ -166,7 +166,7 @@ New checkers
load-plugins=pylint.extensions.emptystring
- to the ``MASTER`` section of your ``.pylintrc`` or using the command::
+ to the ``MAIN`` section of your ``.pylintrc`` or using the command::
$ pylint a.py --load-plugins=pylint.extensions.emptystring
@@ -200,7 +200,7 @@ New checkers
load-plugins=pylint.extensions.comparetozero
- to the ``MASTER`` section of your ``.pylintrc`` or using the command::
+ to the ``MAIN`` section of your ``.pylintrc`` or using the command::
$ pylint a.py --load-plugins=pylint.extensions.comparetozero
diff --git a/doc/whatsnew/2.11.rst b/doc/whatsnew/2.11.rst
index 8d098e140..80885ee4b 100644
--- a/doc/whatsnew/2.11.rst
+++ b/doc/whatsnew/2.11.rst
@@ -67,7 +67,7 @@ Extensions
Other Changes
=============
-* Added ``py-version`` config key (if ``[MASTER]`` section). Used for version dependent checks.
+* Added ``py-version`` config key (if ``[MAIN]`` section). Used for version dependent checks.
Will default to whatever Python version pylint is executed with.
* The ``invalid-name`` message is now more detailed when using multiple naming style regexes.
diff --git a/doc/whatsnew/2.14.rst b/doc/whatsnew/2.14.rst
index 4cabb5f0b..ba8d33fbd 100644
--- a/doc/whatsnew/2.14.rst
+++ b/doc/whatsnew/2.14.rst
@@ -136,6 +136,10 @@ Other Changes
Closes #3312
+* The main checker name is now ``main`` instead of ``master``. The configuration does not need to be updated as sections' name are optional.
+
+ Closes #5467
+
* Update ``invalid-slots-object`` message to show bad object rather than its inferred value.
Closes #6101
diff --git a/examples/pylintrc b/examples/pylintrc
index cebe5d2c1..8a1661072 100644
--- a/examples/pylintrc
+++ b/examples/pylintrc
@@ -1,4 +1,4 @@
-[MASTER]
+[MAIN]
# Analyse import fallback blocks. This can be used to support both Python 2 and
# 3 compatible code, which means that the block might have code that exists
diff --git a/pylint/config/arguments_manager.py b/pylint/config/arguments_manager.py
index f9b5a0a66..1efa0de29 100644
--- a/pylint/config/arguments_manager.py
+++ b/pylint/config/arguments_manager.py
@@ -130,7 +130,7 @@ class _ArgumentsManager:
section_desc = provider.option_groups_descs.get(section, None)
- # We exclude master since its docstring comes from PyLinter
+ # We exclude main since its docstring comes from PyLinter
if provider.name != MAIN_CHECKER_NAME and provider.__doc__:
section_desc = provider.__doc__.split("\n\n")[0]
@@ -662,7 +662,7 @@ class _ArgumentsManager:
for group in sorted(
self._arg_parser._action_groups,
- key=lambda x: (x.title != "Master", x.title),
+ key=lambda x: (x.title != "Main", x.title),
):
# Skip the options section with the --help option
if group.title in {"options", "optional arguments", "Commands"}:
diff --git a/pylint/constants.py b/pylint/constants.py
index 6986b8a4e..2a6276ff3 100644
--- a/pylint/constants.py
+++ b/pylint/constants.py
@@ -46,8 +46,8 @@ MSG_TYPES_STATUS = {"I": 0, "C": 16, "R": 8, "W": 4, "E": 2, "F": 1}
# You probably don't want to change the MAIN_CHECKER_NAME
# This would affect rcfile generation and retro-compatibility
-# on all project using [MASTER] in their rcfile.
-MAIN_CHECKER_NAME = "master"
+# on all project using [MAIN] in their rcfile.
+MAIN_CHECKER_NAME = "main"
USER_HOME = os.path.expanduser("~")
# TODO: 3.0: Remove in 3.0 with all the surrounding code
diff --git a/pylint/extensions/docparams.py b/pylint/extensions/docparams.py
index ba2a21d30..7e0dc12c3 100644
--- a/pylint/extensions/docparams.py
+++ b/pylint/extensions/docparams.py
@@ -39,7 +39,7 @@ class DocstringParameterChecker(BaseChecker):
load-plugins=pylint.extensions.docparams
- to the ``MASTER`` section of your ``.pylintrc``.
+ to the ``MAIN`` section of your ``.pylintrc``.
"""
name = "parameter_documentation"
diff --git a/pylint/extensions/docparams.rst b/pylint/extensions/docparams.rst
index 0021fad0f..5e54354bc 100644
--- a/pylint/extensions/docparams.rst
+++ b/pylint/extensions/docparams.rst
@@ -7,7 +7,7 @@ You can activate this checker by adding the line::
load-plugins=pylint.extensions.docparams
-to the ``MASTER`` section of your ``.pylintrc``.
+to the ``MAIN`` section of your ``.pylintrc``.
This checker verifies that all function, method, and constructor docstrings
include documentation of the
diff --git a/pylint/utils/docs.py b/pylint/utils/docs.py
index 56cecd7d1..75817d1a3 100644
--- a/pylint/utils/docs.py
+++ b/pylint/utils/docs.py
@@ -22,7 +22,7 @@ def _get_checkers_infos(linter: PyLinter) -> dict[str, dict[str, Any]]:
by_checker: dict[str, dict[str, Any]] = {}
for checker in linter.get_checkers():
name = checker.name
- if name != "master":
+ if name != MAIN_CHECKER_NAME:
try:
by_checker[name]["checker"] = checker
with warnings.catch_warnings():
diff --git a/pylintrc b/pylintrc
index 03ae4e578..5e7a6193e 100644
--- a/pylintrc
+++ b/pylintrc
@@ -1,4 +1,4 @@
-[MASTER]
+[MAIN]
# Specify a configuration file.
#rcfile=
diff --git a/tests/config/functional/setup_cfg/identical_name_in_flake8/setup.cfg b/tests/config/functional/setup_cfg/identical_name_in_flake8/setup.cfg
index df4ec3926..51a2c307b 100644
--- a/tests/config/functional/setup_cfg/identical_name_in_flake8/setup.cfg
+++ b/tests/config/functional/setup_cfg/identical_name_in_flake8/setup.cfg
@@ -1,5 +1,5 @@
# Test for the behavior of https://github.com/PyCQA/pylint/issues/4371
-[pylint.MASTER]
+[pylint.MAIN]
persistent=no
ignore = migrations
[flake8]
diff --git a/tests/config/functional/setup_cfg/issue_4272/option_in_wrong_section.cfg b/tests/config/functional/setup_cfg/issue_4272/option_in_wrong_section.cfg
index d362b5eb7..b045873c9 100644
--- a/tests/config/functional/setup_cfg/issue_4272/option_in_wrong_section.cfg
+++ b/tests/config/functional/setup_cfg/issue_4272/option_in_wrong_section.cfg
@@ -1,7 +1,7 @@
# Test for the behaviour of https://github.com/PyCQA/pylint/issues/4272
-[pylint.NOTMASTER]
+[pylint.NOTMAIN]
load-plugins=pylint.extensions.bad_builtin
-[pylint.MASTER]
+[pylint.MAIN]
persistent=no
[pylint.DEPRECATED_BUILTINS]
bad-functions=print,map
diff --git a/tests/config/functional/toml/issue_4746/loaded_plugin_does_not_exists.toml b/tests/config/functional/toml/issue_4746/loaded_plugin_does_not_exists.toml
index c015a9448..fc37545a5 100644
--- a/tests/config/functional/toml/issue_4746/loaded_plugin_does_not_exists.toml
+++ b/tests/config/functional/toml/issue_4746/loaded_plugin_does_not_exists.toml
@@ -1,3 +1,3 @@
# The pylint_websockets plugin does not exist and therefore this toml is invalid
-[tool.pylint.MASTER]
+[tool.pylint.MAIN]
load-plugins = 'pylint_websockets'
diff --git a/tests/functional/a/alternative/alternative_union_syntax.rc b/tests/functional/a/alternative/alternative_union_syntax.rc
index 595070b48..b8ab9047a 100644
--- a/tests/functional/a/alternative/alternative_union_syntax.rc
+++ b/tests/functional/a/alternative/alternative_union_syntax.rc
@@ -1,4 +1,4 @@
-[master]
+[main]
py-version=3.10
[testoptions]
diff --git a/tests/functional/a/alternative/alternative_union_syntax_error.rc b/tests/functional/a/alternative/alternative_union_syntax_error.rc
index ca4c715a7..c4d51566d 100644
--- a/tests/functional/a/alternative/alternative_union_syntax_error.rc
+++ b/tests/functional/a/alternative/alternative_union_syntax_error.rc
@@ -1,4 +1,4 @@
-[master]
+[main]
py-version=3.8
[testoptions]
diff --git a/tests/functional/a/alternative/alternative_union_syntax_py37.rc b/tests/functional/a/alternative/alternative_union_syntax_py37.rc
index ca4c715a7..c4d51566d 100644
--- a/tests/functional/a/alternative/alternative_union_syntax_py37.rc
+++ b/tests/functional/a/alternative/alternative_union_syntax_py37.rc
@@ -1,4 +1,4 @@
-[master]
+[main]
py-version=3.8
[testoptions]
diff --git a/tests/functional/d/deprecated/deprecated_module_py39_earlier_pyversion.rc b/tests/functional/d/deprecated/deprecated_module_py39_earlier_pyversion.rc
index 8118783a1..85f6999e0 100644
--- a/tests/functional/d/deprecated/deprecated_module_py39_earlier_pyversion.rc
+++ b/tests/functional/d/deprecated/deprecated_module_py39_earlier_pyversion.rc
@@ -1,4 +1,4 @@
-[master]
+[main]
py-version=3.8
[testoptions]
diff --git a/tests/functional/e/.#emacs_file_lock_by_conf.rc b/tests/functional/e/.#emacs_file_lock_by_conf.rc
index 4140338cd..920ce8644 100644
--- a/tests/functional/e/.#emacs_file_lock_by_conf.rc
+++ b/tests/functional/e/.#emacs_file_lock_by_conf.rc
@@ -1,2 +1,2 @@
-[MASTER]
+[MAIN]
ignore-patterns=^\.#
diff --git a/tests/functional/e/.#emacs_file_lock_redefined_conf.rc b/tests/functional/e/.#emacs_file_lock_redefined_conf.rc
index f6cf1bf87..8bd9534ee 100644
--- a/tests/functional/e/.#emacs_file_lock_redefined_conf.rc
+++ b/tests/functional/e/.#emacs_file_lock_redefined_conf.rc
@@ -1,3 +1,3 @@
-[MASTER]
+[MAIN]
ignore-patterns=""
disable=non-ascii-name
diff --git a/tests/functional/ext/bad_builtin/bad_builtin_extension.rc b/tests/functional/ext/bad_builtin/bad_builtin_extension.rc
index de9b4244a..e7f2e1dbd 100644
--- a/tests/functional/ext/bad_builtin/bad_builtin_extension.rc
+++ b/tests/functional/ext/bad_builtin/bad_builtin_extension.rc
@@ -1,2 +1,2 @@
-[MASTER]
+[MAIN]
load-plugins=pylint.extensions.bad_builtin,
diff --git a/tests/functional/ext/bad_builtin/bad_builtins.rc b/tests/functional/ext/bad_builtin/bad_builtins.rc
index e32b9f32c..9598ce0f6 100644
--- a/tests/functional/ext/bad_builtin/bad_builtins.rc
+++ b/tests/functional/ext/bad_builtin/bad_builtins.rc
@@ -1,4 +1,4 @@
-[MASTER]
+[MAIN]
load-plugins = pylint.extensions.bad_builtin
[pylint.DEPRECATED_BUILTINS]
diff --git a/tests/functional/ext/broad_try_clause/broad_try_clause_extension.rc b/tests/functional/ext/broad_try_clause/broad_try_clause_extension.rc
index 1737783e0..438a80b6d 100644
--- a/tests/functional/ext/broad_try_clause/broad_try_clause_extension.rc
+++ b/tests/functional/ext/broad_try_clause/broad_try_clause_extension.rc
@@ -1,2 +1,2 @@
-[MASTER]
+[MAIN]
load-plugins=pylint.extensions.broad_try_clause,
diff --git a/tests/functional/ext/check_elif/check_elif.rc b/tests/functional/ext/check_elif/check_elif.rc
index b9b1de49d..4010739ec 100644
--- a/tests/functional/ext/check_elif/check_elif.rc
+++ b/tests/functional/ext/check_elif/check_elif.rc
@@ -1,2 +1,2 @@
-[MASTER]
+[MAIN]
load-plugins=pylint.extensions.check_elif,
diff --git a/tests/functional/ext/code_style/cs_consider_using_assignment_expr.rc b/tests/functional/ext/code_style/cs_consider_using_assignment_expr.rc
index 2a659c07d..6d3ba769b 100644
--- a/tests/functional/ext/code_style/cs_consider_using_assignment_expr.rc
+++ b/tests/functional/ext/code_style/cs_consider_using_assignment_expr.rc
@@ -1,4 +1,4 @@
-[MASTER]
+[MAIN]
load-plugins=pylint.extensions.code_style
py-version=3.8
diff --git a/tests/functional/ext/code_style/cs_consider_using_namedtuple_or_dataclass.rc b/tests/functional/ext/code_style/cs_consider_using_namedtuple_or_dataclass.rc
index 47767a206..8663ab085 100644
--- a/tests/functional/ext/code_style/cs_consider_using_namedtuple_or_dataclass.rc
+++ b/tests/functional/ext/code_style/cs_consider_using_namedtuple_or_dataclass.rc
@@ -1,2 +1,2 @@
-[MASTER]
+[MAIN]
load-plugins=pylint.extensions.code_style
diff --git a/tests/functional/ext/code_style/cs_consider_using_tuple.rc b/tests/functional/ext/code_style/cs_consider_using_tuple.rc
index 47767a206..8663ab085 100644
--- a/tests/functional/ext/code_style/cs_consider_using_tuple.rc
+++ b/tests/functional/ext/code_style/cs_consider_using_tuple.rc
@@ -1,2 +1,2 @@
-[MASTER]
+[MAIN]
load-plugins=pylint.extensions.code_style
diff --git a/tests/functional/ext/code_style/cs_py_version_35.rc b/tests/functional/ext/code_style/cs_py_version_35.rc
index 6f19ec36a..1c2b2fc2e 100644
--- a/tests/functional/ext/code_style/cs_py_version_35.rc
+++ b/tests/functional/ext/code_style/cs_py_version_35.rc
@@ -1,3 +1,3 @@
-[MASTER]
+[MAIN]
load-plugins=pylint.extensions.code_style
py-version=3.5
diff --git a/tests/functional/ext/comparetozero/comparetozero.rc b/tests/functional/ext/comparetozero/comparetozero.rc
index e9b836539..70c6171b5 100644
--- a/tests/functional/ext/comparetozero/comparetozero.rc
+++ b/tests/functional/ext/comparetozero/comparetozero.rc
@@ -1,2 +1,2 @@
-[MASTER]
+[MAIN]
load-plugins=pylint.extensions.comparetozero,
diff --git a/tests/functional/ext/comparison_placement/misplaced_comparison_constant.rc b/tests/functional/ext/comparison_placement/misplaced_comparison_constant.rc
index a8df8ab8b..bece9a583 100644
--- a/tests/functional/ext/comparison_placement/misplaced_comparison_constant.rc
+++ b/tests/functional/ext/comparison_placement/misplaced_comparison_constant.rc
@@ -1,2 +1,2 @@
-[MASTER]
+[MAIN]
load-plugins=pylint.extensions.comparison_placement,
diff --git a/tests/functional/ext/confusing_elif/confusing_elif.rc b/tests/functional/ext/confusing_elif/confusing_elif.rc
index 6a11b2c09..6ceabfd96 100644
--- a/tests/functional/ext/confusing_elif/confusing_elif.rc
+++ b/tests/functional/ext/confusing_elif/confusing_elif.rc
@@ -1,2 +1,2 @@
-[MASTER]
+[MAIN]
load-plugins=pylint.extensions.confusing_elif
diff --git a/tests/functional/ext/consider_ternary_expression/consider_ternary_expression.rc b/tests/functional/ext/consider_ternary_expression/consider_ternary_expression.rc
index 39b1d7975..7aecce4d3 100644
--- a/tests/functional/ext/consider_ternary_expression/consider_ternary_expression.rc
+++ b/tests/functional/ext/consider_ternary_expression/consider_ternary_expression.rc
@@ -1,4 +1,4 @@
-[MASTER]
+[MAIN]
load-plugins=pylint.extensions.consider_ternary_expression,
[MESSAGES CONTROL]
diff --git a/tests/functional/ext/docparams/docparams.rc b/tests/functional/ext/docparams/docparams.rc
index eda78b640..24fa52ef4 100644
--- a/tests/functional/ext/docparams/docparams.rc
+++ b/tests/functional/ext/docparams/docparams.rc
@@ -1,4 +1,4 @@
-[MASTER]
+[MAIN]
load-plugins = pylint.extensions.docparams
[BASIC]
diff --git a/tests/functional/ext/docparams/missing_param_doc.rc b/tests/functional/ext/docparams/missing_param_doc.rc
index d4a6dc172..2e63824f6 100644
--- a/tests/functional/ext/docparams/missing_param_doc.rc
+++ b/tests/functional/ext/docparams/missing_param_doc.rc
@@ -1,4 +1,4 @@
-[MASTER]
+[MAIN]
load-plugins=pylint.extensions.docparams,
[PARAMETER_DOCUMENTATION]
diff --git a/tests/functional/ext/docparams/parameter/missing_param_doc.rc b/tests/functional/ext/docparams/parameter/missing_param_doc.rc
index 4a81d2781..2bd8899cd 100644
--- a/tests/functional/ext/docparams/parameter/missing_param_doc.rc
+++ b/tests/functional/ext/docparams/parameter/missing_param_doc.rc
@@ -1,4 +1,4 @@
-[MASTER]
+[MAIN]
load-plugins = pylint.extensions.docparams
[BASIC]
diff --git a/tests/functional/ext/docparams/parameter/missing_param_doc_required.rc b/tests/functional/ext/docparams/parameter/missing_param_doc_required.rc
index 24cdf9ada..8150c6ff2 100644
--- a/tests/functional/ext/docparams/parameter/missing_param_doc_required.rc
+++ b/tests/functional/ext/docparams/parameter/missing_param_doc_required.rc
@@ -1,4 +1,4 @@
-[MASTER]
+[MAIN]
load-plugins = pylint.extensions.docparams
[BASIC]
diff --git a/tests/functional/ext/docparams/parameter/missing_param_doc_required_Google.rc b/tests/functional/ext/docparams/parameter/missing_param_doc_required_Google.rc
index 24cdf9ada..8150c6ff2 100644
--- a/tests/functional/ext/docparams/parameter/missing_param_doc_required_Google.rc
+++ b/tests/functional/ext/docparams/parameter/missing_param_doc_required_Google.rc
@@ -1,4 +1,4 @@
-[MASTER]
+[MAIN]
load-plugins = pylint.extensions.docparams
[BASIC]
diff --git a/tests/functional/ext/docparams/parameter/missing_param_doc_required_Numpy.rc b/tests/functional/ext/docparams/parameter/missing_param_doc_required_Numpy.rc
index 24cdf9ada..8150c6ff2 100644
--- a/tests/functional/ext/docparams/parameter/missing_param_doc_required_Numpy.rc
+++ b/tests/functional/ext/docparams/parameter/missing_param_doc_required_Numpy.rc
@@ -1,4 +1,4 @@
-[MASTER]
+[MAIN]
load-plugins = pylint.extensions.docparams
[BASIC]
diff --git a/tests/functional/ext/docparams/parameter/missing_param_doc_required_Sphinx.rc b/tests/functional/ext/docparams/parameter/missing_param_doc_required_Sphinx.rc
index 4fc587b6c..671820dbc 100644
--- a/tests/functional/ext/docparams/parameter/missing_param_doc_required_Sphinx.rc
+++ b/tests/functional/ext/docparams/parameter/missing_param_doc_required_Sphinx.rc
@@ -1,4 +1,4 @@
-[MASTER]
+[MAIN]
load-plugins = pylint.extensions.docparams
[BASIC]
diff --git a/tests/functional/ext/docparams/parameter/missing_param_doc_required_min_length.rc b/tests/functional/ext/docparams/parameter/missing_param_doc_required_min_length.rc
index a0538bf1b..40f8c14b1 100644
--- a/tests/functional/ext/docparams/parameter/missing_param_doc_required_min_length.rc
+++ b/tests/functional/ext/docparams/parameter/missing_param_doc_required_min_length.rc
@@ -1,4 +1,4 @@
-[MASTER]
+[MAIN]
load-plugins = pylint.extensions.docparams
[BASIC]
diff --git a/tests/functional/ext/docparams/parameter/missing_param_doc_required_no_doc_rgx_check_init.rc b/tests/functional/ext/docparams/parameter/missing_param_doc_required_no_doc_rgx_check_init.rc
index 3cba99ef4..a9e60fa73 100644
--- a/tests/functional/ext/docparams/parameter/missing_param_doc_required_no_doc_rgx_check_init.rc
+++ b/tests/functional/ext/docparams/parameter/missing_param_doc_required_no_doc_rgx_check_init.rc
@@ -1,4 +1,4 @@
-[MASTER]
+[MAIN]
load-plugins = pylint.extensions.docparams
[BASIC]
diff --git a/tests/functional/ext/docparams/parameter/missing_param_doc_required_no_doc_rgx_check_none.rc b/tests/functional/ext/docparams/parameter/missing_param_doc_required_no_doc_rgx_check_none.rc
index 1196467cd..f976c8211 100644
--- a/tests/functional/ext/docparams/parameter/missing_param_doc_required_no_doc_rgx_check_none.rc
+++ b/tests/functional/ext/docparams/parameter/missing_param_doc_required_no_doc_rgx_check_none.rc
@@ -1,4 +1,4 @@
-[MASTER]
+[MAIN]
load-plugins = pylint.extensions.docparams
[BASIC]
diff --git a/tests/functional/ext/docparams/parameter/missing_param_doc_required_no_doc_rgx_default.rc b/tests/functional/ext/docparams/parameter/missing_param_doc_required_no_doc_rgx_default.rc
index c81f8bd6b..62c9395a7 100644
--- a/tests/functional/ext/docparams/parameter/missing_param_doc_required_no_doc_rgx_default.rc
+++ b/tests/functional/ext/docparams/parameter/missing_param_doc_required_no_doc_rgx_default.rc
@@ -1,4 +1,4 @@
-[MASTER]
+[MAIN]
load-plugins = pylint.extensions.docparams
[BASIC]
diff --git a/tests/functional/ext/docparams/parameter/missing_param_doc_required_no_doc_rgx_test_all.rc b/tests/functional/ext/docparams/parameter/missing_param_doc_required_no_doc_rgx_test_all.rc
index a616b1a66..505fa0440 100644
--- a/tests/functional/ext/docparams/parameter/missing_param_doc_required_no_doc_rgx_test_all.rc
+++ b/tests/functional/ext/docparams/parameter/missing_param_doc_required_no_doc_rgx_test_all.rc
@@ -1,4 +1,4 @@
-[MASTER]
+[MAIN]
load-plugins = pylint.extensions.docparams
[BASIC]
diff --git a/tests/functional/ext/docparams/raise/missing_raises_doc.rc b/tests/functional/ext/docparams/raise/missing_raises_doc.rc
index 3c410593d..4547f9811 100644
--- a/tests/functional/ext/docparams/raise/missing_raises_doc.rc
+++ b/tests/functional/ext/docparams/raise/missing_raises_doc.rc
@@ -1,2 +1,2 @@
-[MASTER]
+[MAIN]
load-plugins = pylint.extensions.docparams
diff --git a/tests/functional/ext/docparams/raise/missing_raises_doc_Google.rc b/tests/functional/ext/docparams/raise/missing_raises_doc_Google.rc
index 3c410593d..4547f9811 100644
--- a/tests/functional/ext/docparams/raise/missing_raises_doc_Google.rc
+++ b/tests/functional/ext/docparams/raise/missing_raises_doc_Google.rc
@@ -1,2 +1,2 @@
-[MASTER]
+[MAIN]
load-plugins = pylint.extensions.docparams
diff --git a/tests/functional/ext/docparams/raise/missing_raises_doc_Numpy.rc b/tests/functional/ext/docparams/raise/missing_raises_doc_Numpy.rc
index 3c410593d..4547f9811 100644
--- a/tests/functional/ext/docparams/raise/missing_raises_doc_Numpy.rc
+++ b/tests/functional/ext/docparams/raise/missing_raises_doc_Numpy.rc
@@ -1,2 +1,2 @@
-[MASTER]
+[MAIN]
load-plugins = pylint.extensions.docparams
diff --git a/tests/functional/ext/docparams/raise/missing_raises_doc_Sphinx.rc b/tests/functional/ext/docparams/raise/missing_raises_doc_Sphinx.rc
index 3c410593d..4547f9811 100644
--- a/tests/functional/ext/docparams/raise/missing_raises_doc_Sphinx.rc
+++ b/tests/functional/ext/docparams/raise/missing_raises_doc_Sphinx.rc
@@ -1,2 +1,2 @@
-[MASTER]
+[MAIN]
load-plugins = pylint.extensions.docparams
diff --git a/tests/functional/ext/docparams/raise/missing_raises_doc_required.rc b/tests/functional/ext/docparams/raise/missing_raises_doc_required.rc
index 098921070..40c032f0d 100644
--- a/tests/functional/ext/docparams/raise/missing_raises_doc_required.rc
+++ b/tests/functional/ext/docparams/raise/missing_raises_doc_required.rc
@@ -1,4 +1,4 @@
-[MASTER]
+[MAIN]
load-plugins = pylint.extensions.docparams
[BASIC]
diff --git a/tests/functional/ext/docparams/raise/missing_raises_doc_required_Google.rc b/tests/functional/ext/docparams/raise/missing_raises_doc_required_Google.rc
index 098921070..40c032f0d 100644
--- a/tests/functional/ext/docparams/raise/missing_raises_doc_required_Google.rc
+++ b/tests/functional/ext/docparams/raise/missing_raises_doc_required_Google.rc
@@ -1,4 +1,4 @@
-[MASTER]
+[MAIN]
load-plugins = pylint.extensions.docparams
[BASIC]
diff --git a/tests/functional/ext/docparams/raise/missing_raises_doc_required_Numpy.rc b/tests/functional/ext/docparams/raise/missing_raises_doc_required_Numpy.rc
index 098921070..40c032f0d 100644
--- a/tests/functional/ext/docparams/raise/missing_raises_doc_required_Numpy.rc
+++ b/tests/functional/ext/docparams/raise/missing_raises_doc_required_Numpy.rc
@@ -1,4 +1,4 @@
-[MASTER]
+[MAIN]
load-plugins = pylint.extensions.docparams
[BASIC]
diff --git a/tests/functional/ext/docparams/raise/missing_raises_doc_required_Sphinx.rc b/tests/functional/ext/docparams/raise/missing_raises_doc_required_Sphinx.rc
index 098921070..40c032f0d 100644
--- a/tests/functional/ext/docparams/raise/missing_raises_doc_required_Sphinx.rc
+++ b/tests/functional/ext/docparams/raise/missing_raises_doc_required_Sphinx.rc
@@ -1,4 +1,4 @@
-[MASTER]
+[MAIN]
load-plugins = pylint.extensions.docparams
[BASIC]
diff --git a/tests/functional/ext/docparams/raise/missing_raises_doc_required_exc_inheritance.rc b/tests/functional/ext/docparams/raise/missing_raises_doc_required_exc_inheritance.rc
index 098921070..40c032f0d 100644
--- a/tests/functional/ext/docparams/raise/missing_raises_doc_required_exc_inheritance.rc
+++ b/tests/functional/ext/docparams/raise/missing_raises_doc_required_exc_inheritance.rc
@@ -1,4 +1,4 @@
-[MASTER]
+[MAIN]
load-plugins = pylint.extensions.docparams
[BASIC]
diff --git a/tests/functional/ext/docparams/return/missing_return_doc.rc b/tests/functional/ext/docparams/return/missing_return_doc.rc
index 3c410593d..4547f9811 100644
--- a/tests/functional/ext/docparams/return/missing_return_doc.rc
+++ b/tests/functional/ext/docparams/return/missing_return_doc.rc
@@ -1,2 +1,2 @@
-[MASTER]
+[MAIN]
load-plugins = pylint.extensions.docparams
diff --git a/tests/functional/ext/docparams/return/missing_return_doc_Google.rc b/tests/functional/ext/docparams/return/missing_return_doc_Google.rc
index 3c410593d..4547f9811 100644
--- a/tests/functional/ext/docparams/return/missing_return_doc_Google.rc
+++ b/tests/functional/ext/docparams/return/missing_return_doc_Google.rc
@@ -1,2 +1,2 @@
-[MASTER]
+[MAIN]
load-plugins = pylint.extensions.docparams
diff --git a/tests/functional/ext/docparams/return/missing_return_doc_Numpy.rc b/tests/functional/ext/docparams/return/missing_return_doc_Numpy.rc
index 3c410593d..4547f9811 100644
--- a/tests/functional/ext/docparams/return/missing_return_doc_Numpy.rc
+++ b/tests/functional/ext/docparams/return/missing_return_doc_Numpy.rc
@@ -1,2 +1,2 @@
-[MASTER]
+[MAIN]
load-plugins = pylint.extensions.docparams
diff --git a/tests/functional/ext/docparams/return/missing_return_doc_Sphinx.rc b/tests/functional/ext/docparams/return/missing_return_doc_Sphinx.rc
index 3c410593d..4547f9811 100644
--- a/tests/functional/ext/docparams/return/missing_return_doc_Sphinx.rc
+++ b/tests/functional/ext/docparams/return/missing_return_doc_Sphinx.rc
@@ -1,2 +1,2 @@
-[MASTER]
+[MAIN]
load-plugins = pylint.extensions.docparams
diff --git a/tests/functional/ext/docparams/return/missing_return_doc_required.rc b/tests/functional/ext/docparams/return/missing_return_doc_required.rc
index 4f8de1a2d..460cbb3df 100644
--- a/tests/functional/ext/docparams/return/missing_return_doc_required.rc
+++ b/tests/functional/ext/docparams/return/missing_return_doc_required.rc
@@ -1,4 +1,4 @@
-[MASTER]
+[MAIN]
load-plugins = pylint.extensions.docparams
[BASIC]
diff --git a/tests/functional/ext/docparams/return/missing_return_doc_required_Google.rc b/tests/functional/ext/docparams/return/missing_return_doc_required_Google.rc
index 4f8de1a2d..460cbb3df 100644
--- a/tests/functional/ext/docparams/return/missing_return_doc_required_Google.rc
+++ b/tests/functional/ext/docparams/return/missing_return_doc_required_Google.rc
@@ -1,4 +1,4 @@
-[MASTER]
+[MAIN]
load-plugins = pylint.extensions.docparams
[BASIC]
diff --git a/tests/functional/ext/docparams/return/missing_return_doc_required_Numpy.rc b/tests/functional/ext/docparams/return/missing_return_doc_required_Numpy.rc
index 4f8de1a2d..460cbb3df 100644
--- a/tests/functional/ext/docparams/return/missing_return_doc_required_Numpy.rc
+++ b/tests/functional/ext/docparams/return/missing_return_doc_required_Numpy.rc
@@ -1,4 +1,4 @@
-[MASTER]
+[MAIN]
load-plugins = pylint.extensions.docparams
[BASIC]
diff --git a/tests/functional/ext/docparams/return/missing_return_doc_required_Sphinx.rc b/tests/functional/ext/docparams/return/missing_return_doc_required_Sphinx.rc
index 4f8de1a2d..460cbb3df 100644
--- a/tests/functional/ext/docparams/return/missing_return_doc_required_Sphinx.rc
+++ b/tests/functional/ext/docparams/return/missing_return_doc_required_Sphinx.rc
@@ -1,4 +1,4 @@
-[MASTER]
+[MAIN]
load-plugins = pylint.extensions.docparams
[BASIC]
diff --git a/tests/functional/ext/docparams/useless_type_doc.rc b/tests/functional/ext/docparams/useless_type_doc.rc
index d4a6dc172..2e63824f6 100644
--- a/tests/functional/ext/docparams/useless_type_doc.rc
+++ b/tests/functional/ext/docparams/useless_type_doc.rc
@@ -1,4 +1,4 @@
-[MASTER]
+[MAIN]
load-plugins=pylint.extensions.docparams,
[PARAMETER_DOCUMENTATION]
diff --git a/tests/functional/ext/docparams/yield/missing_yield_doc.rc b/tests/functional/ext/docparams/yield/missing_yield_doc.rc
index 3c410593d..4547f9811 100644
--- a/tests/functional/ext/docparams/yield/missing_yield_doc.rc
+++ b/tests/functional/ext/docparams/yield/missing_yield_doc.rc
@@ -1,2 +1,2 @@
-[MASTER]
+[MAIN]
load-plugins = pylint.extensions.docparams
diff --git a/tests/functional/ext/docparams/yield/missing_yield_doc_Google.rc b/tests/functional/ext/docparams/yield/missing_yield_doc_Google.rc
index 3c410593d..4547f9811 100644
--- a/tests/functional/ext/docparams/yield/missing_yield_doc_Google.rc
+++ b/tests/functional/ext/docparams/yield/missing_yield_doc_Google.rc
@@ -1,2 +1,2 @@
-[MASTER]
+[MAIN]
load-plugins = pylint.extensions.docparams
diff --git a/tests/functional/ext/docparams/yield/missing_yield_doc_Numpy.rc b/tests/functional/ext/docparams/yield/missing_yield_doc_Numpy.rc
index 3c410593d..4547f9811 100644
--- a/tests/functional/ext/docparams/yield/missing_yield_doc_Numpy.rc
+++ b/tests/functional/ext/docparams/yield/missing_yield_doc_Numpy.rc
@@ -1,2 +1,2 @@
-[MASTER]
+[MAIN]
load-plugins = pylint.extensions.docparams
diff --git a/tests/functional/ext/docparams/yield/missing_yield_doc_Sphinx.rc b/tests/functional/ext/docparams/yield/missing_yield_doc_Sphinx.rc
index 3c410593d..4547f9811 100644
--- a/tests/functional/ext/docparams/yield/missing_yield_doc_Sphinx.rc
+++ b/tests/functional/ext/docparams/yield/missing_yield_doc_Sphinx.rc
@@ -1,2 +1,2 @@
-[MASTER]
+[MAIN]
load-plugins = pylint.extensions.docparams
diff --git a/tests/functional/ext/docparams/yield/missing_yield_doc_required.rc b/tests/functional/ext/docparams/yield/missing_yield_doc_required.rc
index ee2ac61f2..0c0b54795 100644
--- a/tests/functional/ext/docparams/yield/missing_yield_doc_required.rc
+++ b/tests/functional/ext/docparams/yield/missing_yield_doc_required.rc
@@ -1,4 +1,4 @@
-[MASTER]
+[MAIN]
load-plugins = pylint.extensions.docparams
[BASIC]
diff --git a/tests/functional/ext/docparams/yield/missing_yield_doc_required_Google.rc b/tests/functional/ext/docparams/yield/missing_yield_doc_required_Google.rc
index ee2ac61f2..0c0b54795 100644
--- a/tests/functional/ext/docparams/yield/missing_yield_doc_required_Google.rc
+++ b/tests/functional/ext/docparams/yield/missing_yield_doc_required_Google.rc
@@ -1,4 +1,4 @@
-[MASTER]
+[MAIN]
load-plugins = pylint.extensions.docparams
[BASIC]
diff --git a/tests/functional/ext/docparams/yield/missing_yield_doc_required_Numpy.rc b/tests/functional/ext/docparams/yield/missing_yield_doc_required_Numpy.rc
index ee2ac61f2..0c0b54795 100644
--- a/tests/functional/ext/docparams/yield/missing_yield_doc_required_Numpy.rc
+++ b/tests/functional/ext/docparams/yield/missing_yield_doc_required_Numpy.rc
@@ -1,4 +1,4 @@
-[MASTER]
+[MAIN]
load-plugins = pylint.extensions.docparams
[BASIC]
diff --git a/tests/functional/ext/docparams/yield/missing_yield_doc_required_Sphinx.rc b/tests/functional/ext/docparams/yield/missing_yield_doc_required_Sphinx.rc
index ee2ac61f2..0c0b54795 100644
--- a/tests/functional/ext/docparams/yield/missing_yield_doc_required_Sphinx.rc
+++ b/tests/functional/ext/docparams/yield/missing_yield_doc_required_Sphinx.rc
@@ -1,4 +1,4 @@
-[MASTER]
+[MAIN]
load-plugins = pylint.extensions.docparams
[BASIC]
diff --git a/tests/functional/ext/docstyle/docstyle_first_line_empty.rc b/tests/functional/ext/docstyle/docstyle_first_line_empty.rc
index 5128289ff..9b4edb621 100644
--- a/tests/functional/ext/docstyle/docstyle_first_line_empty.rc
+++ b/tests/functional/ext/docstyle/docstyle_first_line_empty.rc
@@ -1,2 +1,2 @@
-[MASTER]
+[MAIN]
load-plugins=pylint.extensions.docstyle,
diff --git a/tests/functional/ext/docstyle/docstyle_quotes.rc b/tests/functional/ext/docstyle/docstyle_quotes.rc
index 5128289ff..9b4edb621 100644
--- a/tests/functional/ext/docstyle/docstyle_quotes.rc
+++ b/tests/functional/ext/docstyle/docstyle_quotes.rc
@@ -1,2 +1,2 @@
-[MASTER]
+[MAIN]
load-plugins=pylint.extensions.docstyle,
diff --git a/tests/functional/ext/empty_comment/empty_comment.rc b/tests/functional/ext/empty_comment/empty_comment.rc
index 1bbd021e7..053552640 100644
--- a/tests/functional/ext/empty_comment/empty_comment.rc
+++ b/tests/functional/ext/empty_comment/empty_comment.rc
@@ -1,2 +1,2 @@
-[MASTER]
+[MAIN]
load-plugins=pylint.extensions.empty_comment,
diff --git a/tests/functional/ext/emptystring/empty_string_comparison.rc b/tests/functional/ext/emptystring/empty_string_comparison.rc
index e6e3ded01..d2826befa 100644
--- a/tests/functional/ext/emptystring/empty_string_comparison.rc
+++ b/tests/functional/ext/emptystring/empty_string_comparison.rc
@@ -1,2 +1,2 @@
-[MASTER]
+[MAIN]
load-plugins=pylint.extensions.emptystring,
diff --git a/tests/functional/ext/eq_without_hash/eq_without_hash.rc b/tests/functional/ext/eq_without_hash/eq_without_hash.rc
index 5a4c9fcce..6e2e015a4 100644
--- a/tests/functional/ext/eq_without_hash/eq_without_hash.rc
+++ b/tests/functional/ext/eq_without_hash/eq_without_hash.rc
@@ -1,2 +1,2 @@
-[MASTER]
+[MAIN]
load-plugins=pylint.extensions.eq_without_hash,
diff --git a/tests/functional/ext/for_any_all/for_any_all.rc b/tests/functional/ext/for_any_all/for_any_all.rc
index 41b0eaa71..2fc820793 100644
--- a/tests/functional/ext/for_any_all/for_any_all.rc
+++ b/tests/functional/ext/for_any_all/for_any_all.rc
@@ -1,2 +1,2 @@
-[MASTER]
+[MAIN]
load-plugins=pylint.extensions.for_any_all
diff --git a/tests/functional/ext/mccabe/mccabe.rc b/tests/functional/ext/mccabe/mccabe.rc
index ac96a1eb5..19b18218e 100644
--- a/tests/functional/ext/mccabe/mccabe.rc
+++ b/tests/functional/ext/mccabe/mccabe.rc
@@ -1,4 +1,4 @@
-[MASTER]
+[MAIN]
load-plugins=pylint.extensions.mccabe,
max-complexity=0
diff --git a/tests/functional/ext/no_self_use/no_self_use.rc b/tests/functional/ext/no_self_use/no_self_use.rc
index 3f87505dd..4a8b2f571 100644
--- a/tests/functional/ext/no_self_use/no_self_use.rc
+++ b/tests/functional/ext/no_self_use/no_self_use.rc
@@ -1,4 +1,4 @@
-[master]
+[main]
load-plugins=pylint.extensions.no_self_use
[testoptions]
diff --git a/tests/functional/ext/overlapping_exceptions/overlapping_exceptions.rc b/tests/functional/ext/overlapping_exceptions/overlapping_exceptions.rc
index ad49162c0..0f64b39ad 100644
--- a/tests/functional/ext/overlapping_exceptions/overlapping_exceptions.rc
+++ b/tests/functional/ext/overlapping_exceptions/overlapping_exceptions.rc
@@ -1,2 +1,2 @@
-[MASTER]
+[MAIN]
load-plugins=pylint.extensions.overlapping_exceptions,
diff --git a/tests/functional/ext/plugin_does_not_exists.rc b/tests/functional/ext/plugin_does_not_exists.rc
index 72e7c1af7..0661a3825 100644
--- a/tests/functional/ext/plugin_does_not_exists.rc
+++ b/tests/functional/ext/plugin_does_not_exists.rc
@@ -1,3 +1,3 @@
-[master]
+[main]
load-plugins=
pylint.extensions.check_does_not_exists_in_venv,
diff --git a/tests/functional/ext/private_import/private_import.rc b/tests/functional/ext/private_import/private_import.rc
index c9bbc23f1..5920812a5 100644
--- a/tests/functional/ext/private_import/private_import.rc
+++ b/tests/functional/ext/private_import/private_import.rc
@@ -1,2 +1,2 @@
-[MASTER]
+[MAIN]
load-plugins=pylint.extensions.private_import,
diff --git a/tests/functional/ext/redefined_loop_name/redefined_loop_name.rc b/tests/functional/ext/redefined_loop_name/redefined_loop_name.rc
index 2785fc59e..5bdbdbe6e 100644
--- a/tests/functional/ext/redefined_loop_name/redefined_loop_name.rc
+++ b/tests/functional/ext/redefined_loop_name/redefined_loop_name.rc
@@ -1,2 +1,2 @@
-[MASTER]
+[MAIN]
load-plugins=pylint.extensions.redefined_loop_name,
diff --git a/tests/functional/ext/redefined_loop_name/reused_outer_loop_variable.rc b/tests/functional/ext/redefined_loop_name/reused_outer_loop_variable.rc
index 2785fc59e..5bdbdbe6e 100644
--- a/tests/functional/ext/redefined_loop_name/reused_outer_loop_variable.rc
+++ b/tests/functional/ext/redefined_loop_name/reused_outer_loop_variable.rc
@@ -1,2 +1,2 @@
-[MASTER]
+[MAIN]
load-plugins=pylint.extensions.redefined_loop_name,
diff --git a/tests/functional/ext/redefined_variable_type/redefined_variable_type.rc b/tests/functional/ext/redefined_variable_type/redefined_variable_type.rc
index 8ee18a8f1..48cfb90be 100644
--- a/tests/functional/ext/redefined_variable_type/redefined_variable_type.rc
+++ b/tests/functional/ext/redefined_variable_type/redefined_variable_type.rc
@@ -1,2 +1,2 @@
-[MASTER]
+[MAIN]
load-plugins=pylint.extensions.redefined_variable_type,
diff --git a/tests/functional/ext/redefined_variable_type/regression_newtype_fstring.rc b/tests/functional/ext/redefined_variable_type/regression_newtype_fstring.rc
index 8ee18a8f1..48cfb90be 100644
--- a/tests/functional/ext/redefined_variable_type/regression_newtype_fstring.rc
+++ b/tests/functional/ext/redefined_variable_type/regression_newtype_fstring.rc
@@ -1,2 +1,2 @@
-[MASTER]
+[MAIN]
load-plugins=pylint.extensions.redefined_variable_type,
diff --git a/tests/functional/ext/set_membership/use_set_membership.rc b/tests/functional/ext/set_membership/use_set_membership.rc
index 688dcbc31..d7d2a3001 100644
--- a/tests/functional/ext/set_membership/use_set_membership.rc
+++ b/tests/functional/ext/set_membership/use_set_membership.rc
@@ -1,2 +1,2 @@
-[MASTER]
+[MAIN]
load-plugins=pylint.extensions.set_membership
diff --git a/tests/functional/ext/typing/typing_broken_callable.rc b/tests/functional/ext/typing/typing_broken_callable.rc
index 301a67b7c..5841196f2 100644
--- a/tests/functional/ext/typing/typing_broken_callable.rc
+++ b/tests/functional/ext/typing/typing_broken_callable.rc
@@ -1,4 +1,4 @@
-[master]
+[main]
py-version=3.9
load-plugins=pylint.extensions.typing
diff --git a/tests/functional/ext/typing/typing_broken_callable_deprecated_alias.rc b/tests/functional/ext/typing/typing_broken_callable_deprecated_alias.rc
index 301a67b7c..5841196f2 100644
--- a/tests/functional/ext/typing/typing_broken_callable_deprecated_alias.rc
+++ b/tests/functional/ext/typing/typing_broken_callable_deprecated_alias.rc
@@ -1,4 +1,4 @@
-[master]
+[main]
py-version=3.9
load-plugins=pylint.extensions.typing
diff --git a/tests/functional/ext/typing/typing_broken_callable_future_import.rc b/tests/functional/ext/typing/typing_broken_callable_future_import.rc
index 301a67b7c..5841196f2 100644
--- a/tests/functional/ext/typing/typing_broken_callable_future_import.rc
+++ b/tests/functional/ext/typing/typing_broken_callable_future_import.rc
@@ -1,4 +1,4 @@
-[master]
+[main]
py-version=3.9
load-plugins=pylint.extensions.typing
diff --git a/tests/functional/ext/typing/typing_broken_noreturn.rc b/tests/functional/ext/typing/typing_broken_noreturn.rc
index 56e0bed57..eb28fc75b 100644
--- a/tests/functional/ext/typing/typing_broken_noreturn.rc
+++ b/tests/functional/ext/typing/typing_broken_noreturn.rc
@@ -1,3 +1,3 @@
-[master]
+[main]
py-version=3.7
load-plugins=pylint.extensions.typing
diff --git a/tests/functional/ext/typing/typing_broken_noreturn_future_import.rc b/tests/functional/ext/typing/typing_broken_noreturn_future_import.rc
index 92ef9524a..282a65d62 100644
--- a/tests/functional/ext/typing/typing_broken_noreturn_future_import.rc
+++ b/tests/functional/ext/typing/typing_broken_noreturn_future_import.rc
@@ -1,4 +1,4 @@
-[master]
+[main]
py-version=3.7
load-plugins=pylint.extensions.typing
diff --git a/tests/functional/ext/typing/typing_broken_noreturn_py372.rc b/tests/functional/ext/typing/typing_broken_noreturn_py372.rc
index 24550b2c9..236c2fbc7 100644
--- a/tests/functional/ext/typing/typing_broken_noreturn_py372.rc
+++ b/tests/functional/ext/typing/typing_broken_noreturn_py372.rc
@@ -1,3 +1,3 @@
-[master]
+[main]
py-version=3.7.2
load-plugins=pylint.extensions.typing
diff --git a/tests/functional/ext/typing/typing_consider_using_alias.rc b/tests/functional/ext/typing/typing_consider_using_alias.rc
index f77f58ef4..4e5e75f5d 100644
--- a/tests/functional/ext/typing/typing_consider_using_alias.rc
+++ b/tests/functional/ext/typing/typing_consider_using_alias.rc
@@ -1,4 +1,4 @@
-[master]
+[main]
py-version=3.8
load-plugins=pylint.extensions.typing
diff --git a/tests/functional/ext/typing/typing_consider_using_alias_without_future.rc b/tests/functional/ext/typing/typing_consider_using_alias_without_future.rc
index f77f58ef4..4e5e75f5d 100644
--- a/tests/functional/ext/typing/typing_consider_using_alias_without_future.rc
+++ b/tests/functional/ext/typing/typing_consider_using_alias_without_future.rc
@@ -1,4 +1,4 @@
-[master]
+[main]
py-version=3.8
load-plugins=pylint.extensions.typing
diff --git a/tests/functional/ext/typing/typing_consider_using_union.rc b/tests/functional/ext/typing/typing_consider_using_union.rc
index f77f58ef4..4e5e75f5d 100644
--- a/tests/functional/ext/typing/typing_consider_using_union.rc
+++ b/tests/functional/ext/typing/typing_consider_using_union.rc
@@ -1,4 +1,4 @@
-[master]
+[main]
py-version=3.8
load-plugins=pylint.extensions.typing
diff --git a/tests/functional/ext/typing/typing_consider_using_union_py310.rc b/tests/functional/ext/typing/typing_consider_using_union_py310.rc
index 65b4e34fc..a35db1577 100644
--- a/tests/functional/ext/typing/typing_consider_using_union_py310.rc
+++ b/tests/functional/ext/typing/typing_consider_using_union_py310.rc
@@ -1,4 +1,4 @@
-[master]
+[main]
py-version=3.10
load-plugins=pylint.extensions.typing
diff --git a/tests/functional/ext/typing/typing_consider_using_union_without_future.rc b/tests/functional/ext/typing/typing_consider_using_union_without_future.rc
index f77f58ef4..4e5e75f5d 100644
--- a/tests/functional/ext/typing/typing_consider_using_union_without_future.rc
+++ b/tests/functional/ext/typing/typing_consider_using_union_without_future.rc
@@ -1,4 +1,4 @@
-[master]
+[main]
py-version=3.8
load-plugins=pylint.extensions.typing
diff --git a/tests/functional/ext/typing/typing_deprecated_alias.rc b/tests/functional/ext/typing/typing_deprecated_alias.rc
index abd4136bb..a4a4c9022 100644
--- a/tests/functional/ext/typing/typing_deprecated_alias.rc
+++ b/tests/functional/ext/typing/typing_deprecated_alias.rc
@@ -1,4 +1,4 @@
-[master]
+[main]
py-version=3.9
load-plugins=pylint.extensions.typing
diff --git a/tests/functional/ext/while_used/while_used.rc b/tests/functional/ext/while_used/while_used.rc
index 28e1b1faf..034579724 100644
--- a/tests/functional/ext/while_used/while_used.rc
+++ b/tests/functional/ext/while_used/while_used.rc
@@ -1,2 +1,2 @@
-[MASTER]
+[MAIN]
load-plugins=pylint.extensions.while_used,
diff --git a/tests/functional/p/protected_access_special_methods_off.rc b/tests/functional/p/protected_access_special_methods_off.rc
index 47c987ccc..62c584a72 100644
--- a/tests/functional/p/protected_access_special_methods_off.rc
+++ b/tests/functional/p/protected_access_special_methods_off.rc
@@ -1,2 +1,2 @@
-[MASTER]
+[MAIN]
check-protected-access-in-special-methods=no
diff --git a/tests/functional/p/protected_access_special_methods_on.rc b/tests/functional/p/protected_access_special_methods_on.rc
index 8ad93c164..c5dfa5f4b 100644
--- a/tests/functional/p/protected_access_special_methods_on.rc
+++ b/tests/functional/p/protected_access_special_methods_on.rc
@@ -1,2 +1,2 @@
-[MASTER]
+[MAIN]
check-protected-access-in-special-methods=yes
diff --git a/tests/functional/p/py_version_35.rc b/tests/functional/p/py_version_35.rc
index 2d8d65197..c37d6cb65 100644
--- a/tests/functional/p/py_version_35.rc
+++ b/tests/functional/p/py_version_35.rc
@@ -1,2 +1,2 @@
-[MASTER]
+[MAIN]
py-version=3.5
diff --git a/tests/functional/r/regression/regression_issue_4631.rc b/tests/functional/r/regression/regression_issue_4631.rc
index 88cdb85bf..2e435fea2 100644
--- a/tests/functional/r/regression/regression_issue_4631.rc
+++ b/tests/functional/r/regression/regression_issue_4631.rc
@@ -1,2 +1,2 @@
-[MASTER]
+[MAIN]
limit-inference-results=0
diff --git a/tests/functional/u/unsupported/unsupported_version_for_final.rc b/tests/functional/u/unsupported/unsupported_version_for_final.rc
index d10f4f3c2..77eb3be64 100644
--- a/tests/functional/u/unsupported/unsupported_version_for_final.rc
+++ b/tests/functional/u/unsupported/unsupported_version_for_final.rc
@@ -1,2 +1,2 @@
-[master]
+[main]
py-version=3.7
diff --git a/tests/message/unittest_message_id_store.py b/tests/message/unittest_message_id_store.py
index 17af97908..f300b4f19 100644
--- a/tests/message/unittest_message_id_store.py
+++ b/tests/message/unittest_message_id_store.py
@@ -111,7 +111,7 @@ def test_exclusivity_of_msgids() -> None:
# Some pairs are hard-coded as they are pre-existing and non-exclusive,
# and we don't want to rename them for backwards compatibility
checker_id_pairs = {
- "00": ("master", "miscellaneous"),
+ "00": ("main", "miscellaneous"),
"01": (
"basic",
"refactoring",
diff --git a/tests/regrtest_data/dummy_plugin.rc b/tests/regrtest_data/dummy_plugin.rc
index 162dedc89..989ed1995 100644
--- a/tests/regrtest_data/dummy_plugin.rc
+++ b/tests/regrtest_data/dummy_plugin.rc
@@ -1,4 +1,4 @@
-[MASTER]
+[MAIN]
load-plugins=dummy_plugin
[DUMMY_PLUGIN]
diff --git a/tests/test_check_parallel.py b/tests/test_check_parallel.py
index 149bdb6e1..259c236d4 100644
--- a/tests/test_check_parallel.py
+++ b/tests/test_check_parallel.py
@@ -303,7 +303,7 @@ class TestCheckParallel:
arguments=["--enable", "R9999"],
)
assert len(linter.get_checkers()) == 2, (
- "We should only have the 'master' and 'sequential-checker' "
+ "We should only have the 'main' and 'sequential-checker' "
"checkers registered"
)
assert {
diff --git a/tests/test_self.py b/tests/test_self.py
index 813a1dbac..3241f547a 100644
--- a/tests/test_self.py
+++ b/tests/test_self.py
@@ -1174,7 +1174,7 @@ class TestRunTC:
rcfile = tmpdir / "pylintrc"
rcfile_contents = textwrap.dedent(
f"""
- [MASTER]
+ [MAIN]
output={output_file}
"""
)
@@ -1334,7 +1334,8 @@ class TestCallbackOptions:
encoding="utf-8",
check=False,
)
- assert "[MASTER]" in process.stdout
+ assert "[MAIN]" in process.stdout
+ assert "[MASTER]" not in process.stdout
assert "profile" not in process.stdout
args = _add_rcfile_default_pylintrc(["--generate-rcfile"])
process_two = subprocess.run(
@@ -1370,10 +1371,10 @@ class TestCallbackOptions:
# Get rid of the pesky messages that pylint emits if the
# configuration file is not found.
pattern = rf"\[{MAIN_CHECKER_NAME.upper()}"
- master = re.search(pattern, output)
- assert master is not None, f"{pattern} not found in {output}"
+ main = re.search(pattern, output)
+ assert main is not None, f"{pattern} not found in {output}"
- out = StringIO(output[master.start() :])
+ out = StringIO(output[main.start() :])
parser = configparser.RawConfigParser()
parser.read_file(out)
messages = utils._splitstrip(parser.get("MESSAGES CONTROL", "disable"))
@@ -1394,7 +1395,8 @@ class TestCallbackOptions:
encoding="utf-8",
check=False,
)
- assert "[tool.pylint.master]" in process.stdout
+ assert "[tool.pylint.main]" in process.stdout
+ assert "[tool.pylint.master]" not in process.stdout
assert '"positional arguments"' not in process.stdout
assert '"optional arguments"' not in process.stdout
assert 'preferred-modules = ["a:b"]' in process.stdout
diff --git a/tests/testutils/data/init_hook.rc b/tests/testutils/data/init_hook.rc
index b0efa254b..19f79b19c 100644
--- a/tests/testutils/data/init_hook.rc
+++ b/tests/testutils/data/init_hook.rc
@@ -1,3 +1,3 @@
-[MASTER]
+[MAIN]
init-hook=raise RuntimeError
diff --git a/tests/benchmark/test_baseline_benchmarks.py b/tests/benchmark/test_baseline_benchmarks.py
index e96d58bbe..6fb1cdf18 100644
--- a/tests/benchmark/test_baseline_benchmarks.py
+++ b/tests/benchmark/test_baseline_benchmarks.py
@@ -124,7 +124,7 @@ class TestEstablishBaselineBenchmarks:
linter = PyLinter(reporter=Reporter())
fileinfos = [self.empty_filepath] # Single file to end-to-end the system
assert linter.config.jobs == 1
- assert len(linter._checkers) == 1, "Should just have 'master'"
+ assert len(linter._checkers) == 1, "Should just have 'main'"
benchmark(linter.check, fileinfos)
assert (
linter.msg_status == 0
@@ -147,7 +147,7 @@ class TestEstablishBaselineBenchmarks:
fileinfos = [self.empty_filepath for _ in range(linter.config.jobs)]
assert linter.config.jobs == 2
- assert len(linter._checkers) == 1, "Should have 'master'"
+ assert len(linter._checkers) == 1, "Should have 'main'"
benchmark(linter.check, fileinfos)
assert (
linter.msg_status == 0
@@ -161,16 +161,16 @@ class TestEstablishBaselineBenchmarks:
# Create file per worker, using all workers
fileinfos = [self.empty_file_info for _ in range(linter.config.jobs)]
- assert len(linter._checkers) == 1, "Should have 'master'"
+ assert len(linter._checkers) == 1, "Should have 'main'"
benchmark(check_parallel, linter, jobs=2, files=fileinfos)
assert (
linter.msg_status == 0
), f"Expected no errors to be thrown: {pprint.pformat(linter.reporter.messages)}"
def test_baseline_lots_of_files_j1(self, benchmark):
"""Establish a baseline with only 'master' checker being run in -j1.
We do not register any checkers except the default 'master', so the cost is just
that of the system with a lot of files registered
"""
if benchmark.disabled:
@@ -180,7 +180,7 @@ class TestEstablishBaselineBenchmarks:
linter.config.jobs = 1
fileinfos = [self.empty_filepath for _ in range(self.lot_of_files)]
assert linter.config.jobs == 1
- assert len(linter._checkers) == 1, "Should have 'master'"
+ assert len(linter._checkers) == 1, "Should have 'main'"
benchmark(linter.check, fileinfos)
assert (
linter.msg_status == 0
@@ -188,10 +188,10 @@ class TestEstablishBaselineBenchmarks:
@pytest.mark.needs_two_cores
def test_baseline_lots_of_files_j2(self, benchmark):
"""Establish a baseline with only 'master' checker being run in -j2.
As with the -j1 variant above `test_baseline_lots_of_files_j1`, we do not
register any checkers except the default 'master', so the cost is just that of
the check_parallel system across 2 workers, plus the overhead of PyLinter
"""
if benchmark.disabled:
@@ -201,7 +201,7 @@ class TestEstablishBaselineBenchmarks:
linter.config.jobs = 2
fileinfos = [self.empty_filepath for _ in range(self.lot_of_files)]
assert linter.config.jobs == 2
- assert len(linter._checkers) == 1, "Should have 'master'"
+ assert len(linter._checkers) == 1, "Should have 'main'"
benchmark(linter.check, fileinfos)
assert (
linter.msg_status == 0
@@ -221,7 +221,7 @@ class TestEstablishBaselineBenchmarks:
linter.register_checker(NoWorkChecker(linter))
fileinfos = [self.empty_filepath for _ in range(self.lot_of_files)]
assert linter.config.jobs == 1
- assert len(linter._checkers) == 2, "Should have 'master' and 'sleeper'"
+ assert len(linter._checkers) == 2, "Should have 'main' and 'sleeper'"
benchmark(linter.check, fileinfos)
assert (
linter.msg_status == 0
@@ -242,7 +242,7 @@ class TestEstablishBaselineBenchmarks:
linter.register_checker(NoWorkChecker(linter))
fileinfos = [self.empty_filepath for _ in range(self.lot_of_files)]
assert linter.config.jobs == 2
- assert len(linter._checkers) == 2, "Should have 'master' and 'sleeper'"
+ assert len(linter._checkers) == 2, "Should have 'main' and 'sleeper'"
benchmark(linter.check, fileinfos)
assert (
linter.msg_status == 0
@@ -268,7 +268,7 @@ class TestEstablishBaselineBenchmarks:
fileinfos = [self.empty_filepath for _ in range(2)]
assert linter.config.jobs == 1
- assert len(linter._checkers) == 2, "Should have 'master' and 'sleeper'"
+ assert len(linter._checkers) == 2, "Should have 'main' and 'sleeper'"
benchmark(linter.check, fileinfos)
assert (
linter.msg_status == 0
@@ -296,7 +296,7 @@ class TestEstablishBaselineBenchmarks:
fileinfos = [self.empty_filepath for _ in range(2)]
assert linter.config.jobs == 2
- assert len(linter._checkers) == 2, "Should have 'master' and 'sleeper'"
+ assert len(linter._checkers) == 2, "Should have 'main' and 'sleeper'"
benchmark(linter.check, fileinfos)
assert (
linter.msg_status == 0
@@ -308,7 +308,7 @@ class TestEstablishBaselineBenchmarks:
runner = benchmark(Run, args, reporter=Reporter(), exit=False)
assert runner.linter.config.jobs == 1
print("len(runner.linter._checkers)", len(runner.linter._checkers))
- assert len(runner.linter._checkers) > 1, "Should have more than 'master'"
+ assert len(runner.linter._checkers) > 1, "Should have more than 'main'"
assert (
runner.linter.msg_status == 0
@@ -338,5 +338,5 @@ class TestEstablishBaselineBenchmarks:
assert linter.config.jobs == 1
print("len(linter._checkers)", len(linter._checkers))
- assert len(linter._checkers) > 1, "Should have more than 'master'"
+ assert len(linter._checkers) > 1, "Should have more than 'main'"
benchmark(linter.check, fileinfos)
@@ -161,16 +161,16 @@ class TestEstablishBaselineBenchmarks:
), f"Expected no errors to be thrown: {pprint.pformat(linter.reporter.messages)}"
def test_baseline_lots_of_files_j1(self, benchmark):
- """Establish a baseline with only 'master' checker being run in -j1.
+ """Establish a baseline with only 'main' checker being run in -j1.
- We do not register any checkers except the default 'master', so the cost is just
+ We do not register any checkers except the default 'main', so the cost is just
that of the system with a lot of files registered
"""
@@ -188,10 +188,10 @@ class TestEstablishBaselineBenchmarks:
def test_baseline_lots_of_files_j2(self, benchmark):
- """Establish a baseline with only 'master' checker being run in -j2.
+ """Establish a baseline with only 'main' checker being run in -j2.
As with the -j1 variant above `test_baseline_lots_of_files_j1`, we do not
@@ -188,10 +188,10 @@ class TestEstablishBaselineBenchmarks:
As with the -j1 variant above `test_baseline_lots_of_files_j1`, we do not
- register any checkers except the default 'master', so the cost is just that of
+ register any checkers except the default 'main', so the cost is just that of
the check_parallel system across 2 workers, plus the overhead of PyLinter
"""